@@ -11,13 +11,11 @@ import coloredlogs
 
 def get_local_time():
     return datetime.now().strftime('%Y-%m-%d %H:%M:%S')
-
-
 class Logger(object):
     _instance = None
 
     @classmethod
-    def get_logger(cls, level='DEBUG', write_to_file=False, log_path='/tmp/log-{}'.format(get_local_time())):
+    def get_logger(cls, level='INFO', write_to_file=False, log_path='/tmp/log-{}'.format(get_local_time())):
         if cls._instance:
             return cls._instance
         write_to_file = write_to_file
@@ -50,6 +48,8 @@ class Logger(object):
             print("\033[1;36m{}\033[0m \033[1;34mPERFORMANCE: {} consumes {} seconds\033[0m".format(get_local_time(), func.__name__, end -start))
         return wrapper        
 
+defautl_logger = Logger().get_logger()
+
 if __name__ == '__main__':
     # calculate_time()
     # Logger.get_logger().warning("This is a test warning.")
